==> nextcloud-23.0.3.tgz: nextcloud/apps/activity/l10n/ne.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "प्रतिलिपि गरियो!",
    "Not supported!" : "समर्थित छैन!",
    "Press ⌘-C to copy." : "प्रतिलिपि गर्न ⌘-C थिच्नुहोस्।",
    "Press Ctrl-C to copy." : "प्रतिलिपि गर्न Ctrl-C थिच्नुहोस्।",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restricted)",
    "Home" : "गृह",
    "in {path}" : "{path} मा",
    "This stream will show events like additions, changes & shares" : "यो स्ट्रिमले घटनाहरू जस्तै एडअनहरू, परिवर्तनहरू र साझा गरिएका कुराहरू देखाउनेछ",
    "There are no events for this filter" : "यस फिल्टरका लागि कुनै घटनाहरू छैनन्",
    "Today" : "आज",
    "Yesterday" : "हिजो",
    "Personal activity feed for %s" : "%sको व्यक्तिगत गतिविधि फिड",
    "Your feed URL is invalid" : "तपाईंको फिड URL अवैध छ",
    "Your settings have been updated." : "तपाईंको सेटिङहरू अद्यावधिक गरिएको छ।",
    "Settings have been updated." : "सेटिङहरू अद्यावधिक गरिएको छ।",
    "_and %n more _::_and %n more _" : ["र थप %n","र %n थप "],
    "All activities" : "सबै गतिविधिहरू",
    "By others" : "अरूद्वारा",
    "By you" : "तपाईं द्वारा",
    "Hello %s" : "नमस्ते %s",
    "Hello %s," : "नमस्ते %s,",
    "There was some activity at %s" : "%s मा केही गतिविधि थियो",
    "Mail" : "पत्र",
    "Activity" : "गतिविधि",
    "No activity yet" : "अझै सम्म कुनै क्रियाकलाप छैन",
    "Activity feed" : "गतिविधि पाटि",
    "Default settings" : "पूर्वनिर्धारित सेटिङहरू",
    "You need to set up your email address before you can receive notification emails." : "अग्रसूचना ईमेलहरू प्राप्त गर्नु अघि तपाईंले आफ्नो ईमेल ठेगाना सेट अप गर्न आवश्यक छ।",
    "As soon as possible" : "सकेसम्म चाँडै",
    "Hourly" : "घण्टाको हिसाबले",
    "Daily" : "दैनिक",
    "Weekly" : "साप्ताहिक",
    "Settings" : "सेटिङ्हरू",
    "Enable RSS feed" : "RSS फिड सक्षम गर्नुहोस्",
    "RSS feed" : "RSS फिड",
    "No more events to load" : "लोड गर्न थप घटनाहरू छैनन्",
    "An error occurred while loading activities" : "क्रियाकलापहरू लोड गर्दा त्रुटि देखापर्यो",
    "Load more activities" : "थप क्रियाकलापहरू लोड गर्नुहोस्"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.8.tgz: nextcloud/apps/activity/l10n/ne.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "प्रतिलिपि गरियो!",
    "Not supported!" : "समर्थित छैन!",
    "Press ⌘-C to copy." : "प्रतिलिपि गर्न ⌘-C थिच्नुहोस्।",
    "Press Ctrl-C to copy." : "प्रतिलिपि गर्न Ctrl-C थिच्नुहोस्।",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restricted)",
    "Home" : "गृह",
    "in {path}" : "{path} मा",
    "This stream will show events like additions, changes & shares" : "यो स्ट्रिमले घटनाहरू जस्तै एडअनहरू, परिवर्तनहरू र साझा गरिएका कुराहरू देखाउनेछ",
    "There are no events for this filter" : "यस फिल्टरका लागि कुनै घटनाहरू छैनन्",
    "Today" : "आज",
    "Yesterday" : "हिजो",
    "Personal activity feed for %s" : "%sको व्यक्तिगत गतिविधि फिड",
    "Your feed URL is invalid" : "तपाईंको फिड URL अवैध छ",
    "Your settings have been updated." : "तपाईंको सेटिङहरू अद्यावधिक गरिएको छ।",
    "Settings have been updated." : "सेटिङहरू अद्यावधिक गरिएको छ।",
    "_and %n more _::_and %n more _" : ["र थप %n","र %n थप "],
    "All activities" : "सबै गतिविधिहरू",
    "By others" : "अरूद्वारा",
    "By you" : "तपाईं द्वारा",
    "Hello %s" : "नमस्ते %s",
    "Hello %s," : "नमस्ते %s,",
    "There was some activity at %s" : "%s मा केही गतिविधि थियो",
    "Mail" : "पत्र",
    "Activity" : "गतिविधि",
    "No activity yet" : "अझै सम्म कुनै क्रियाकलाप छैन",
    "Activities" : "क्रियाकलापहरू",
    "No activities" : "कुनै गतिविधि छैन",
    "Activity feed" : "गतिविधि पाटि",
    "Default settings" : "पूर्वनिर्धारित सेटिङहरू",
    "You need to set up your email address before you can receive notification emails." : "अग्रसूचना ईमेलहरू प्राप्त गर्नु अघि तपाईंले आफ्नो ईमेल ठेगाना सेट अप गर्न आवश्यक छ।",
    "As soon as possible" : "सकेसम्म चाँडै",
    "Hourly" : "घण्टाको हिसाबले",
    "Daily" : "दैनिक",
    "Weekly" : "साप्ताहिक",
    "Enable RSS feed" : "RSS फिड सक्षम गर्नुहोस्",
    "RSS feed" : "RSS फिड",
    "No more events to load" : "लोड गर्न थप घटनाहरू छैनन्",
    "Settings" : "सेटिङ्हरू"
},
"nplurals=2; plural=(n != 1);");
